! app.css
<< https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/css/bootstrap.min.css
<< https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css
< css/layout.css
< css/bootstrap-select.min.css

! app.js
<< https://code.jquery.com/jquery-3.7.1.min.js
<< https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/js/bootstrap.bundle.min.js
< js/common.js
< js/bootstrap-select.min.js
